@@ -172,15 +172,17 @@ If PATTERN is omitted, it defaults to \"[ \\f\\t\\n\\r\\v]+\"."
 
             An Interactive Plotting Program
              Thomas Williams & Colin Kelley
-          Version 4.2 organized by: Hans-Bernhard Broeker
+                Version 4.6 organized by:
+    Hans-Bernhard Broeker, Ethan A Merritt, and others
 
- Copyright (C) 1986 - 1993, 1998, 2004   Thomas Williams, Colin Kelley
+   Copyright (C) 1986 - 1993, 1998, 2004   Thomas Williams, Colin Kelley
+           Copyright (C) 2004 - 2011  various authors
 
        Mailing list for comments: gnuplot-info@@lists.sourceforge.net
      Mailing list for bug reports: gnuplot-bugs@@lists.sourceforge.net
 
          This manual was originally prepared by Dick Crawford
-                   Version 4.2 - 1 Oct 2006
+                   Version 4.6 - December 2011
 
 
 Major contributors (alphabetic order):
@@ -246,14 +248,13 @@ Major contributors (alphabetic order):
 (setq d2t-terminal-list
       '("aed"
 	"ai"
-	"amiga"
-	"apollo"
 	"aquaterm"
-	"atariaes"
-	"atarivdi"
 	"be"
+	"cairo"
+	"canvas"
 	"cgi"
 	"cgm"
+	"context"
 	"corel"
 	"debug"
 	"djsvga"
@@ -271,7 +272,6 @@ Major contributors (alphabetic order):
 	"gd"
 	"ggi"
 	"gif"
-	"gnugraph"
 	"gpic"
 	"gpr"
 	"grass"
@@ -282,17 +282,16 @@ Major contributors (alphabetic order):
 	"hpljii"
 	"hppj"
 	"imagen"
-	"iris4d"
 	"jpeg"
 	"kyo"
 	"latex"
 	"linux"
+	"lua"
 	"mac"
 	"metafont"
 	"metapost"
 	"mgr"
 	"mif"
-	"multitos"
 	"next"
 	"openstep"
 	"pbm"
@@ -304,7 +303,6 @@ Major contributors (alphabetic order):
 	"pstricks"
 	"qms"
 	"regis"
-	"rgip"
 	"sun"
 	"svg"
 	"t410x"
@@ -312,14 +310,15 @@ Major contributors (alphabetic order):
 	"tek"
 	"texdraw"
 	"tgif"
+	"tikz"
 	"tkcanvas"
 	"tpic"
 	"unixpc"
-	"unixplot"
 	"v384"
 	"vgagl"
 	"vws"
 	"win"
+	"wxt"
 	"x11"
 	"xlib"))
 
@@ -409,12 +408,12 @@ particular conversion chore."
     (if (string-match "linux" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
 					'("linux"))))
-    (if (string-match "amiga" system-configuration)
+    (if (string-match "canvas" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
-					'("amiga"))))
-    (if (string-match "atari" system-configuration)
+					'("canvas"))))
+    (if (string-match "lua" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
-					'("atarivdi" "multitos" "atariaes"))))
+					'("lua" "tikz"))))
     (if (string-match "mac" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
 					'("mac" "openstep"))))
@@ -433,9 +432,6 @@ particular conversion chore."
     (if (string-match "os2" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
 					'("pm" "emxvga"))))
-    (if (string-match "irix" system-configuration)
-	(setq d2t-terminal-list (append d2t-terminal-list
-					'("iris4d"))))
     (if (string-match "sco" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
 					'("cgi"))))
@@ -445,7 +441,7 @@ particular conversion chore."
     (if (string-match "vms" system-configuration)
 	(setq d2t-terminal-list (append d2t-terminal-list
 					'("vws"))))
-    (unless (member* system-configuration '("dos" "windows" "atari" "amiga")
+    (unless (member* system-configuration '("pc" "windows")
 		     :test 'string-match)
       (setq d2t-terminal-list
 	    (append d2t-terminal-list
@@ -611,6 +607,9 @@ appropriate sectioning and @node commands."
 	       (eol  (save-excursion (end-of-line) (point-marker))))
 	  ;; some node names appear twice.  make the second one unique.
 	  ;; this will fail to work if a third pops up in the future!
+	  (if (member* node d2t-node-list :test 'string=)
+	      (setq node (concat node "_")))
+	  ;; this is a fast hack to account for a third equal node name
 	  (if (member* node d2t-node-list :test 'string=)
 	      (setq node (concat node "_")))
 	  (setq d2t-node-list (append d2t-node-list (list node)))
@@ -665,11 +664,12 @@ comment out the multi-word ? entries."
 
 (defun d2t-comments ()
   "Delete comments and lines beginning with # or %.
-# and % lines are used in converting tables into various formats."
+# and % lines are used in converting tables into various formats.
+Also ignore F lines denoting figures."
   (and d2t-verbose (message "  Doing d2t-comments ..."))
   (save-excursion
     (while (not (eobp))
-      (re-search-forward "^[C#%]" (point-max) "to_end")
+      (re-search-forward "^[C#%F]" (point-max) "to_end")
       (unless (eobp)
 	(let ((eol  (save-excursion (end-of-line)
 				    (forward-char 1)
@@ -761,7 +761,7 @@ This must be run after `d2t-first-column'."
 	      ;(insert "@c fix me!!  ")
 	      (beginning-of-line)
 	      (if (looking-at (concat "\\^\\s-*<a\\s-+href=" ; opening tag
-				      "\"\\([^\"]+\\)\">\\s-*" ; url
+				      "\"\\([^\"]+\\)\">\\s-*\n*\\s-*" ; url
 				      "\\([^<]+\\)" ; text
 				      "[ \t]*\\^?</a>" ; closing tag
 				      ))
