@@ -52,6 +52,7 @@
 /* Default point size is taken from the global "pointsize" variable */
 #define PTSZ_DEFAULT    (-2)
 #define PTSZ_VARIABLE   (-3)
+#define AS_VARIABLE	(-3)
 
 /* Type definitions */
 
@@ -91,8 +92,11 @@ typedef struct text_label {
 
 /* This is the default state for the axis, timestamp, and plot title labels
  * indicated by tag = -2 */
+#define NONROTATABLE_LABEL_TAG -2
+#define ROTATE_IN_3D_LABEL_TAG -3
 #define EMPTY_LABELSTRUCT \
-    {NULL, -2, {character, character, character, 0.0, 0.0, 0.0}, CENTRE, 0, 0, \
+    {NULL, NONROTATABLE_LABEL_TAG, \
+     {character, character, character, 0.0, 0.0, 0.0}, CENTRE, 0, 0, \
      NULL, NULL, {TC_LT, -2, 0.0}, DEFAULT_LP_STYLE_TYPE, \
      {character, character, character, 0.0, 0.0, 0.0}, FALSE }
 
@@ -116,6 +120,8 @@ typedef struct rectangle {
     t_position tr;		/* top right */
 } t_rectangle;
 
+#define DEFAULT_RADIUS (-1.0)
+#define DEFAULT_ELLIPSE (-2.0)
 typedef struct circle {
     int type;			/* not used */
     t_position center;		/* center */
@@ -124,8 +130,11 @@ typedef struct circle {
     double arc_end;
 } t_circle;
 
+#define ELLIPSEAXES_XY (0)
+#define ELLIPSEAXES_XX (1)
+#define ELLIPSEAXES_YY (2)
 typedef struct ellipse {
-    int type;			/* not used */
+    int type;			/* mapping of axes: ELLIPSEAXES_XY, ELLIPSEAXES_XX or ELLIPSEAXES_YY */
     t_position center;		/* center */
     t_position extent;		/* major and minor axes */
     double orientation;		/* angle of first axis to horizontal */
@@ -228,6 +237,25 @@ typedef enum histogram_type {
 } t_histogram_type;
 #define DEFAULT_HISTOGRAM_STYLE { HT_NONE, 2, 1, 0.0, 0.0, LT_UNDEFINED, LT_UNDEFINED, 0, NULL, EMPTY_LABELSTRUCT }
 
+typedef enum en_boxplot_factor_labels {
+	BOXPLOT_FACTOR_LABELS_OFF,
+	BOXPLOT_FACTOR_LABELS_AUTO,
+	BOXPLOT_FACTOR_LABELS_X,
+	BOXPLOT_FACTOR_LABELS_X2
+} t_boxplot_factor_labels;
+
+typedef struct boxplot_style {
+    int limit_type;	/* 0 = multiple of interquartile 1 = fraction of points */
+    double limit_value;
+    TBOOLEAN outliers;
+    int pointtype;
+    int plotstyle;	/* CANDLESTICKS or FINANCEBARS */
+    double separation;	/* of boxplots if there are more than one factors */
+    t_boxplot_factor_labels labels;	/* Which axis to put the tic labels if there are factors */
+    TBOOLEAN sort_factors;	/* Sort factors in alphabetical order? */
+} boxplot_style;
+extern boxplot_style boxplot_opts;
+#define DEFAULT_BOXPLOT_STYLE { 0, 1.5, TRUE, 6, CANDLESTICKS, 1.0, BOXPLOT_FACTOR_LABELS_AUTO, FALSE }
 
 /***********************************************************/
 /* Variables defined by gadgets.c needed by other modules. */
@@ -262,6 +290,7 @@ typedef struct {
     double width_fix;		/* user specified additional (+/-) width of key titles */
     double height_fix;
     keytitle_type auto_titles;	/* auto title curves unless plotted 'with notitle' */
+    TBOOLEAN front;		/* draw key in a second pass after the rest of the graph */
     TBOOLEAN reverse;		/* key back to front */
     TBOOLEAN invert;		/* key top to bottom */
     TBOOLEAN enhanced;		/* enable/disable enhanced text of key titles */
@@ -270,11 +299,13 @@ typedef struct {
     char *font;			/* Will be used for both key title and plot titles */
     struct t_colorspec textcolor;	/* Will be used for both key title and plot titles */
     BoundingBox bounds;
+    int maxcols;		/* maximum no of columns for horizontal keys */
+    int maxrows;		/* maximum no of rows for vertical keys */
 } legend_key;
 
 extern legend_key keyT;
 
-# define DEFAULT_KEYBOX_LP { 0, LT_NODRAW, 0, 1.0, 1.0, 0 }
+#define DEFAULT_KEYBOX_LP {0, LT_NODRAW, 0, 0, 1.0, PTSZ_DEFAULT, FALSE, DEFAULT_COLORSPEC}
 
 #define DEFAULT_KEY_POSITION { graph, graph, graph, 0.9, 0.9, 0. }
 
@@ -286,10 +317,11 @@ extern legend_key keyT;
 		GPKEY_RIGHT, GPKEY_VERTICAL, \
 		4.0, 1.0, 0.0, 0.0, \
 		FILENAME_KEYTITLES, \
-		FALSE, FALSE, TRUE, \
+		FALSE, FALSE, FALSE, TRUE, \
 		DEFAULT_KEYBOX_LP, \
 		"", \
-		NULL, {TC_LT, LT_BLACK, 0.0} }
+		NULL, {TC_LT, LT_BLACK, 0.0}, \
+		{0,0,0,0}, 0, 0 }
 
 
 /*
@@ -345,6 +377,7 @@ extern struct arrow_def *first_arrow;
 extern struct text_label *first_label;
 
 extern struct linestyle_def *first_linestyle;
+extern struct linestyle_def *first_perm_linestyle;
 
 extern struct arrowstyle_def *first_arrowstyle;
 
@@ -368,6 +401,7 @@ extern TBOOLEAN	polar;
 extern double zero;		/* zero threshold, not 0! */
 
 extern double pointsize;
+extern double pointintervalbox;
 
 #define SOUTH		1 /* 0th bit */
 #define WEST		2 /* 1th bit */
@@ -383,6 +417,7 @@ extern int user_border;
 extern int border_layer;
 
 extern struct lp_style_type border_lp;
+extern const struct lp_style_type background_lp;
 extern const struct lp_style_type default_border_lp;
 
 extern TBOOLEAN	clip_lines1;
@@ -453,23 +488,24 @@ extern fill_style_type default_fillstyle;
 extern struct object default_rectangle;
 #define DEFAULT_RECTANGLE_STYLE { NULL, -1, 0, OBJ_RECTANGLE,	\
 	{FS_SOLID, 100, 0, BLACK_COLORSPEC},   			\
-	{1, LT_BACKGROUND, 0, 0, 1.0, 0.0, FALSE, DEFAULT_COLORSPEC}, \
+	{0, LT_BACKGROUND, 0, 0, 1.0, 0.0, FALSE, BACKGROUND_COLORSPEC}, \
 	{.rectangle = {0, {0,0,0,0.,0.,0.}, {0,0,0,0.,0.,0.}, {0,0,0,0.,0.,0.}, {0,0,0,0.,0.,0.}}} }
 
 extern struct object default_circle;
 #define DEFAULT_CIRCLE_STYLE { NULL, -1, 0, OBJ_CIRCLE,       \
 	{FS_SOLID, 100, 0, BLACK_COLORSPEC},   			\
-	{1, LT_BACKGROUND, 0, 0, 1.0, 0.0, FALSE, DEFAULT_COLORSPEC},			\
+	{0, LT_BACKGROUND, 0, 0, 1.0, 0.0, FALSE, BACKGROUND_COLORSPEC},			\
 	{.circle = {1, {0,0,0,0.,0.,0.}, {graph,0,0,0.02,0.,0.}, 0., 360. }} }
 
-#define DEFAULT_ELLIPSE_STYLE { NULL, -1, 0, OBJ_CIRCLE,       \
+extern struct object default_ellipse;
+#define DEFAULT_ELLIPSE_STYLE { NULL, -1, 0, OBJ_ELLIPSE,       \
 	{FS_SOLID, 100, 0, BLACK_COLORSPEC},   			\
-	{1, LT_BACKGROUND, 0, 0, 1.0, 0.0, FALSE, DEFAULT_COLORSPEC}, \
-	{.ellipse = {1, {0,0,0,0.,0.,0.}, {0,0,0,0.,0.,0.}, 0. }} }
+	{0, LT_BACKGROUND, 0, 0, 1.0, 0.0, FALSE, BACKGROUND_COLORSPEC}, \
+	{.ellipse = {ELLIPSEAXES_XY, {0,0,0,0.,0.,0.}, {graph,graph,0,0.05,0.03,0.}, 0. }} }
 
 #define DEFAULT_POLYGON_STYLE { NULL, -1, 0, OBJ_POLYGON,       \
 	{FS_SOLID, 100, 0, BLACK_COLORSPEC},   			\
-	{1, LT_BLACK, 0, 0, 1.0, 0.0, FALSE, DEFAULT_COLORSPEC}, \
+	{0, LT_BLACK, 0, 0, 1.0, 0.0, FALSE, BLACK_COLORSPEC}, \
 	{.polygon = {0, NULL} } }
 
 #endif
