@@ -1,5 +1,5 @@
 /*
- * $Id: wxt_term.h,v 1.11 2009/03/26 00:49:18 sfeam Exp $
+ * $Id: wxt_term.h,v 1.16 2011/11/06 04:06:10 sfeam Exp $
  */
 
 /* GNUPLOT - wxt_term.h */
@@ -90,6 +90,8 @@ void wxt_enhanced_flush();
 void wxt_enhanced_writec(int c);
 void wxt_enhanced_open(char* fontname, double fontsize, double base, TBOOLEAN widthflag, TBOOLEAN showflag, int overprint);
 
+void wxt_layer(t_termlayer layer);
+
 void wxt_raise_terminal_window __PROTO((int));
 void wxt_raise_terminal_group __PROTO((void));
 void wxt_lower_terminal_window __PROTO((int));
@@ -101,11 +103,17 @@ void wxt_update_size __PROTO((int number));
 /* state variables shared between wxt.trm and wxt_gui.cpp */
 extern int wxt_window_number;
 extern TBOOLEAN wxt_enhanced_enabled;
+extern TBOOLEAN wxt_dashed;
+extern double wxt_dashlength;
+extern int wxt_background;
+extern rgb_color wxt_rgb_background;
 extern int wxt_persist;
 extern int wxt_raise;
 extern int wxt_ctrl;
+extern int wxt_toggle;
 extern char wxt_set_fontname[MAX_ID_LEN + 1];
 extern int wxt_set_fontsize;
+extern double wxt_set_fontscale;
 extern int wxt_rounded;
 extern char wxt_title[MAX_ID_LEN + 1];
 extern int wxt_width;
